@@ -5,12 +5,6 @@
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
-#
-#    Most of the following was copied shamelessly from nova @
-#    https://github.com/openstack/nova/blob/master/nova/image/glance.py
-#    It's the way nova talks to glance, though obviously
-#    s/python-glanceclient/python-novaclient
-
 #
 #         http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -20,6 +14,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+
+#    Most of the following was copied shamelessly from nova @
+#    https://github.com/openstack/nova/blob/master/nova/image/glance.py
+#    It's the way nova talks to glance, though obviously
+#    s/python-glanceclient/python-novaclient
+
+
 """A client library for accessing Heat CloudFormations API using Boto"""
 
 from os import environ as env
@@ -101,10 +102,12 @@ class HeatClient(object):
             LOG.exception(e)
             return False
 
-    def get_stack(self):
+    def get_stack(self, name=None):
         """Get overcloud Heat template."""
+        if name is None:
+            name = CONF.heat['stack_name']
         if self.connection:
-            return self.connection.stacks.get(CONF.heat['stack_name'])
+            return self.connection.stacks.get(name)
 
     def get_template(self):
         """Get JSON representation of the Heat overcloud template."""
@@ -134,9 +137,11 @@ class HeatClient(object):
             LOG.exception(e)
             return False
 
-    def exists_stack(self):
+    def exists_stack(self, name=None):
+        if name is None:
+            name = CONF.heat['stack_name']
         try:
-            self.get_stack()
+            self.get_stack(name)
             return True
         #return false if 404
         except HeatStackNotFound:
